@@ -22,9 +22,9 @@
 
 #include <kcompletion_export.h>
 
-#include <QtCore/QObject>
-#include <QtCore/QStringList>
-#include <QtCore/QPointer>
+#include <QObject>
+#include <QStringList>
+#include <QPointer>
 #include <QKeySequence>
 
 class KCompTreeNode;
@@ -33,6 +33,8 @@ class KCompletionMatchesWrapper;
 class KCompletionMatches;
 
 /**
+ * @class KCompletion kcompletion.h KCompletion
+ *
  * @short A generic class for completing QStrings
  *
  * This class offers easy use of "auto completion", "manual completion" or
